TimestampState

Struct TimestampState 

pub(crate) struct TimestampState {
    date: Option<Date>,
    time: Option<Time>,
    date_state: <Date as ComponentProvider>::State,
}
State used by Timestamp to cache computed date and time values.

Date and Time are cached separately, with the Date’s state being stored to allow for reusing existing methods.

Fields

date: Option<Date>time: Option<Time>date_state: <Date as ComponentProvider>::State