pub(crate) struct DateState {
day: Option<NonZero<u8>>,
month: Option<Month>,
iso_week: Option<NonZero<u8>>,
iso_year_is_initialized: bool,
iso_year: MaybeUninit<i32>,
}Expand description
State used by date-providing types to cache computed values.
This is used to avoid redundant computations when multiple date components are almost certainly going to be requested within the same formatting invocation.
Fields
day: Option<NonZero<u8>>month: Option<Month>iso_week: Option<NonZero<u8>>iso_year_is_initialized: booliso_year: MaybeUninit<i32>Trait Implementations